package org.rykov.gismeteo.common;

/**
 * This class describes forecast data.
 * @author rykov
 * @created 17.10.2008 16:56:27
 */
public class Forecast {

    /** The day of the month for which forecast prepared (1-31). */
    private int day;

    /** The month of the year for which forecast prepared (1-12). */
    private int month;

    /** The year for which forecast prepared. */
    private int year;

    /** The hour of the local time for which forecast prepared (0-23). */
    private int hour;

    /** The time of the day for which forecast prepared (0-3). */
    private int tod;

    /** The night constant for the time of the day. */
    public static final int TOD_NIGHT = 0;

    /** The morning constant for the time of the day. */
    public static final int TOD_MORNING = 1;

    /** The day constant for the time of the day. */
    public static final int TOD_DAY = 2;

    /** The evening constant for the time of the day. */
    public static final int TOD_EVENING = 3;

    /** The advance time of predictions in hours. */
    private int predict;

    /** The day of the week for which forecast prepared (1-7, starting Sunday). */
    private int weekday;

    /** The air phenomena. */
    private Phenomena phenomena;

    /** The air pressure (mmHg). */
    private Range pressure;

    /** The air temperature (Celsius). */
    private Range temperature;

    /** The wind. */
    private Wind wind;

    /** The relative air humidity. */
    private Range relwet;

    /** The subjective comfort air temperature. */
    private Range heat;

    public int getDay() {
        return day;
    }

    public void setDay(int day) {
        this.day = day;
    }

    public int getMonth() {
        return month;
    }

    public void setMonth(int month) {
        this.month = month;
    }

    public int getYear() {
        return year;
    }

    public void setYear(int year) {
        this.year = year;
    }

    public int getHour() {
        return hour;
    }

    public void setHour(int hour) {
        this.hour = hour;
    }

    public int getTod() {
        return tod;
    }

    public void setTod(int tod) {
        this.tod = tod;
    }

    public int getPredict() {
        return predict;
    }

    public void setPredict(int predict) {
        this.predict = predict;
    }

    public int getWeekday() {
        return weekday;
    }

    public void setWeekday(int weekday) {
        this.weekday = weekday;
    }

    public Phenomena getPhenomena() {
        return phenomena;
    }

    public void setPhenomena(Phenomena phenomena) {
        this.phenomena = phenomena;
    }

    public Range getPressure() {
        return pressure;
    }

    public void setPressure(Range pressure) {
        this.pressure = pressure;
    }

    public Range getTemperature() {
        return temperature;
    }

    public void setTemperature(Range temperature) {
        this.temperature = temperature;
    }

    public Wind getWind() {
        return wind;
    }

    public void setWind(Wind wind) {
        this.wind = wind;
    }

    public Range getRelwet() {
        return relwet;
    }

    public void setRelwet(Range relwet) {
        this.relwet = relwet;
    }

    public Range getHeat() {
        return heat;
    }

    public void setHeat(Range heat) {
        this.heat = heat;
    }
}
