package org.rykov.gismeteo.idea;

import org.rykov.gismeteo.ui.Resources;
import org.rykov.gismeteo.common.Document;
import org.rykov.gismeteo.common.CountryInfo;
import org.rykov.gismeteo.common.TownInfo;

import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;

/**
 * This class creates the gismeteo configuration panel.
 * @author rykov
 * @created 22.10.2008 18:20:23
 */
public class GismeteoConfiguration extends JPanel {

    /** The index field. */
    private JTextField index = new JTextField(8);

    /** The country combobox. */
    private JComboBox country = new JComboBox();

    /** The town combobox. */
    private JComboBox town = new JComboBox();

    /** The towns. */
    private Document towns;

    /**
     * Creates the panel.
     * @param countries the countries
     * @param towns the towns
     */
    public GismeteoConfiguration(Document countries, Document towns) {
        super(new GridBagLayout());
        this.towns = towns;
        GridBagConstraints c = new GridBagConstraints();
        c.anchor = GridBagConstraints.NORTHWEST;
        c.gridwidth = GridBagConstraints.REMAINDER;
        c.weightx = 1;
        add(new JLabel(Resources.get("conf.index")), c);
        add(index, c);
        add(new JLabel(Resources.get("conf.choose.label")), c);
        JPanel panel = new JPanel(new GridLayout(2, 2));
        panel.add(new JLabel(Resources.get("conf.country")));
        panel.add(new JLabel(Resources.get("conf.town")));
        country = new JComboBox();
        panel.add(country);
        town = new JComboBox();
        panel.add(town);
        add(panel, c);
        JButton choose = new JButton(Resources.get("conf.choose"));
        c.weighty = 1;
        add(choose, c);
        country.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                Object sc = country.getSelectedItem();
                if (sc != null) {
                    town.removeAllItems();
                    for (TownInfo ti : GismeteoConfiguration.this.towns.getTowns()) {
                        if (ti.getCountry_en().equals(sc)) {
                            town.addItem(ti.getName_en());
                        }
                    }
                }
            }
        });
        choose.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                Object st = town.getSelectedItem();
                if (st != null) {
                    for (TownInfo ti : GismeteoConfiguration.this.towns.getTowns()) {
                        if (ti.getName_en().equals(st)) {
                            index.setText(ti.getIndex());
                            break;
                        }
                    }
                }
            }
        });
        for (CountryInfo ci : countries.getCountries()) {
            country.addItem(ci.getName_en());
        }
    }

    public String getIndex() {
        return index.getText();
    }

    public void setIndex(String index) {
        this.index.setText(index);
        for (TownInfo ti : towns.getTowns()) {
            if (ti.getIndex().equals(index)) {
                country.setSelectedItem(ti.getCountry_en());
                town.setSelectedItem(ti.getName_en());
                break;
            }
        }
    }
}
