package org.rykov.gismeteo.idea;

import com.intellij.openapi.components.ProjectComponent;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.wm.ToolWindowManager;
import com.intellij.openapi.wm.ToolWindow;
import com.intellij.openapi.wm.ToolWindowAnchor;
import com.intellij.ui.content.ContentFactory;
import com.intellij.ui.content.Content;
import com.intellij.peer.PeerFactory;
import org.jetbrains.annotations.NotNull;
import org.rykov.gismeteo.common.MMWeather;
import org.rykov.gismeteo.ui.Icons;

import java.util.Observer;
import java.util.Observable;
import java.net.URLDecoder;

/**
 * This class defines the project component.
 * @author rykov
 * @created 21.10.2008 13:07:09
 */
public class GismeteoProjectComponent implements ProjectComponent {

    /** The application component. */
    private GismeteoApplicationComponent gac;

    /** The tool window manager. */
    private ToolWindowManager toolWindowManager;

    /** The Gismeteo tool panel. */
    private GismeteoPanel gismeteoPanel = new GismeteoPanel();

    /** The gismeteo tool window. */
    private ToolWindow toolWindow;

    /**
     * Creates the project componentn and register observer to weather changes.
     * @param project the project
     * @param gac the application component
     */
    public GismeteoProjectComponent(Project project, GismeteoApplicationComponent gac) {
        toolWindowManager = ToolWindowManager.getInstance(project);
        this.gac = gac;
    }

    public void initComponent() {}

    public void disposeComponent() {}

    @NotNull
    public String getComponentName() {
        return "GismeteoProjectComponent";
    }

    public void projectOpened() {
        registerToolWindow();
        gac.addObserver(new Observer() {
            public void update(Observable o, Object arg) {
                updateGismeteoPanel();
            }
        });
    }

    public void projectClosed() {
        unregisterToolWindow();
    }

    /**
     * Registers the Gismeteo tool window.
     */
    private void registerToolWindow() {
        toolWindow = toolWindowManager.registerToolWindow(GismeteoPanel.TOOL_WINDOW_ID, false, ToolWindowAnchor.BOTTOM);
        ContentFactory contentFactory = PeerFactory.getInstance().getContentFactory();
        Content content = contentFactory.createContent(gismeteoPanel, null, false);
        toolWindow.getContentManager().addContent(content);
        updateGismeteoPanel();
    }

    /**
     * Unregisters the Gismeteo tool window.
     */
    private void unregisterToolWindow() {
        toolWindowManager.unregisterToolWindow(GismeteoPanel.TOOL_WINDOW_ID);
    }

    /**
     * Updates the Gismeteo tool window.
     */
    public void updateGismeteoPanel() {
        MMWeather weather = gac.getWeather();
        if (weather != null) {
            String name = gac.getTownName(weather.getReport().getTown().getIndex());
            if (name == null) {
                name = URLDecoder.decode(weather.getReport().getTown().getSname());
            }
            toolWindow.setTitle(name);
            toolWindow.setIcon(Icons.generate(weather, toolWindow.getComponent()));
            gismeteoPanel.update(weather);
        }
    }
}
