package org.rykov.gismeteo.sax;

import org.xml.sax.helpers.DefaultHandler;
import org.xml.sax.Attributes;
import org.xml.sax.SAXException;
import org.rykov.gismeteo.common.*;

import java.util.ArrayList;

/**
 * This class defines MMWEATHER handler.
 * @author rykov
 * @created 29.10.2008 16:10:26
 */
public class MMWeatherHandler extends DefaultHandler {

    /** The root weather object. */
    private MMWeather weather;

    /** The report object. */
    private Report report;

    /** The town object. */
    private Town town;

    /** The current forecast object. */
    private Forecast forecast;

    public void startElement(String uri, String localName, String qName, Attributes attributes) throws SAXException {
        if (qName.equals("MMWEATHER")) {
            weather = new MMWeather();
        } else if (qName.equals("REPORT")) {
            report = new Report();
            report.setType(attributes.getValue("type"));
            weather.setReport(report);
        } else if (qName.equals("TOWN")) {
            town = new Town();
            town.setIndex(attributes.getValue("index"));
            town.setSname(attributes.getValue("sname"));
            town.setLatitude(parseInt(attributes.getValue("latitude")));
            town.setLongitude(parseInt(attributes.getValue("longitude")));
            town.setForecasts(new ArrayList<Forecast>());
            report.setTown(town);
        } else if (qName.equals("FORECAST")) {
            forecast = new Forecast();
            forecast.setDay(parseInt(attributes.getValue("day")));
            forecast.setMonth(parseInt(attributes.getValue("month")));
            forecast.setYear(parseInt(attributes.getValue("year")));
            forecast.setHour(parseInt(attributes.getValue("hour")));
            forecast.setTod(parseInt(attributes.getValue("tod")));
            forecast.setPredict(parseInt(attributes.getValue("predict")));
            forecast.setWeekday(parseInt(attributes.getValue("weekday")));
            town.getForecasts().add(forecast);
        } else if (qName.equals("PHENOMENA")) {
            Phenomena phenomena = new Phenomena();
            phenomena.setCloudiness(parseInt(attributes.getValue("cloudiness")));
            phenomena.setPrecipitation(parseInt(attributes.getValue("precipitation")));
            phenomena.setRpower(parseInt(attributes.getValue("rpower")));
            phenomena.setSpower(parseInt(attributes.getValue("spower")));
            forecast.setPhenomena(phenomena);
        } else if (qName.equals("PRESSURE")) {
            forecast.setPressure(parseRange(attributes));
        } else if (qName.equals("TEMPERATURE")) {
            forecast.setTemperature(parseRange(attributes));
        } else if (qName.equals("WIND")) {
            Wind wind = new Wind();
            wind.setMin(parseInt(attributes.getValue("min")));
            wind.setMax(parseInt(attributes.getValue("max")));
            wind.setDirection(parseInt(attributes.getValue("direction")));
            forecast.setWind(wind);
        } else if (qName.equals("RELWET")) {
            forecast.setRelwet(parseRange(attributes));
        } else if (qName.equals("HEAT")) {
            forecast.setHeat(parseRange(attributes));
        }
    }

    /**
     * Parses the integer string.
     * @param string the string
     * @return the integer
     * @throws SAXException the exception
     */
    private int parseInt(String string) throws SAXException {
        try {
            return Integer.parseInt(string);
        } catch (NumberFormatException e) {
            throw new SAXException("Can't parse integer attribute", e);
        }
    }

    /**
     * Parses the range.
     * @param attributes the attributes
     * @return the range
     * @throws SAXException the exception
     */
    private Range parseRange(Attributes attributes) throws SAXException {
        Range range = new Range();
        range.setMin(parseInt(attributes.getValue("min")));
        range.setMax(parseInt(attributes.getValue("max")));
        return range;
    }

    public MMWeather getWeather() {
        return weather;
    }
}
