package org.rykov.gismeteo.ui;

import org.rykov.gismeteo.common.Forecast;
import org.rykov.gismeteo.common.Range;
import org.rykov.gismeteo.common.Wind;
import org.rykov.gismeteo.common.Phenomena;

import javax.swing.table.AbstractTableModel;
import javax.swing.*;
import java.util.List;

/**
 * This class defines the forecast table model.
 * @author rykov
 * @created 21.10.2008 10:24:33
 */
public class ForecastTableModel extends AbstractTableModel {

    /** The forecast list. */
    private List<Forecast> list;

    /**
     * Creates the table model
     * @param list the forecast list
     */
    public ForecastTableModel(List<Forecast> list) {
        this.list = list;
    }

    public int getRowCount() {
        return 7;
    }

    public int getColumnCount() {
        return list.size() + 1;
    }

    public Object getValueAt(int row, int column) {
        if (column == 0) {
            switch (row) {
                case 0: // date
                    return Resources.get("title.date");
                case 1: // cloudiness
                    return Resources.get("title.cloudiness");
                case 2: // temperature
                    return Resources.get("title.temperature");
                case 3: // wind
                    return Resources.get("title.wind");
                case 4: // pressure
                    return Resources.get("title.pressure");
                case 5: // humidity
                    return Resources.get("title.humidity");
                case 6: // comfort
                    return Resources.get("title.comfort");
            }
        } else {
            Forecast forecast = list.get(column - 1);
            switch (row) {
                case 0: // date
                    return Utils.TODS[forecast.getTod()] + " " + forecast.getDay() + "." + forecast.getMonth() + "." +
                            forecast.getYear() + " " + Utils.WEEKDAYS[forecast.getWeekday()]
                            //+ " l=" + forecast.getHour() + " p=" + forecast.getPredict()
                            ;
                case 1: // cloudiness
                    Phenomena phenomena = forecast.getPhenomena();
                    return new IconCell(Utils.getIcon(phenomena.getPrecipitation(),
                            phenomena.getCloudiness(), forecast.getTod()), null,
                            Utils.getIconTip(phenomena.getPrecipitation(), phenomena.getCloudiness()));
                case 2: // temperature
                    Range temperature = forecast.getTemperature();
                    return Utils.formatTemperature(temperature.getMin()) + "-" + Math.abs(temperature.getMax()) + Utils.OC;
                case 3: // wind
                    Wind wind = forecast.getWind();
                    return Utils.DIRECTIONS[wind.getDirection()] + " " + wind.getMin() + "-" + wind.getMax() + Utils.MS;
                case 4: // pressure
                    Range pressure = forecast.getPressure();
                    return pressure.getMin() + "-" + pressure.getMax() + Utils.MHG;
                case 5: // humidity
                    Range relwet = forecast.getRelwet();
                    return relwet.getMin() + "-" + relwet.getMax() + Utils.PERCENT;
                case 6: // comfort
                    Range comfort = forecast.getHeat();
                    return Utils.formatTemperature(comfort.getMin()) + "-" + Math.abs(comfort.getMax()) + Utils.OC;
            }
        }
        return null;
    }
}
