package org.rykov.gismeteo.ui;

import sun.reflect.Reflection;

import javax.swing.*;
import java.awt.image.BufferedImage;
import java.awt.*;
import java.util.Calendar;

import org.rykov.gismeteo.common.MMWeather;
import org.rykov.gismeteo.common.Phenomena;
import org.rykov.gismeteo.common.Forecast;
import org.rykov.gismeteo.common.Range;

/**
 * This class defines the icon utilities.
 * @author rykov
 * @created 20.10.2008 17:45:15
 */
public class Icons {

    /** The path to icon resources. */
    private static final String PATH = "/org/rykov/gismeteo/resources/icons/";

    /** The icon height. */
    private static int ICON_HEIGHT = 16;

    /** The icon width. */
    private static int ICON_WIDTH = 16;

    /** The gap between text and image. */
    private static int ICON_GAP = 5;

    /**
     * Gets the icon by image name.
     * @param name the icon name
     * @return the icon
     */
    public static Icon get(String name) {
        return new ImageIcon(Reflection.getCallerClass(1).getResource(PATH + name));
    }

    /**
     * Generates the tool window icon.
     * @param weather the weather forecast
     * @param c the toolbar component
     * @return the icon
     */
    public static Icon generate(MMWeather weather, Component c) {
        Forecast forecast = null;
        Calendar calendar = Calendar.getInstance();
        int tod = calendar.get(Calendar.HOUR_OF_DAY) / 6;
        for (Forecast f : weather.getReport().getTown().getForecasts()) {
            if (f.getYear() == calendar.get(Calendar.YEAR) &&
                f.getMonth() == calendar.get(Calendar.MONTH) + 1 &&
                f.getDay() == calendar.get(Calendar.DAY_OF_MONTH) &&
                f.getTod() == tod) {
                forecast = f;
                break;
            }
        }
        if (forecast == null) {
            forecast = weather.getReport().getTown().getForecasts().get(0);
        }
        Range temperature = forecast.getTemperature();
        Phenomena phenomena = forecast.getPhenomena();
        Icon icon = Utils.getIcon(phenomena.getPrecipitation(), phenomena.getCloudiness(), forecast.getTod());
        String t = Utils.formatTemperature((temperature.getMin() + temperature.getMax()) / 2) + Utils.OC;
        FontMetrics fm = c.getFontMetrics(c.getFont());
        BufferedImage image = new BufferedImage(ICON_WIDTH + ICON_GAP * 2 + fm.stringWidth(t),
                ICON_HEIGHT, BufferedImage.TYPE_INT_ARGB);
        if (icon != null) {
            icon.paintIcon(null, image.getGraphics(), 0, 0);
        }
        Graphics g = image.getGraphics();
        g.setFont(c.getFont());
        g.setColor(c.getForeground());
        g.drawString(t, ICON_WIDTH + ICON_GAP, (ICON_HEIGHT + fm.getAscent()) / 2);
        return new ImageIcon(image);
    }
}
