package org.rykov.gismeteo.ui;

import org.rykov.gismeteo.common.Forecast;
import org.rykov.gismeteo.common.Phenomena;

import javax.swing.*;

/**
 * This class defines various utility methods.
 * @author rykov
 * @created 22.10.2008 12:00:24
 */
public class Utils {

    /** The hour in ms. */
    public final static long HOUR = 60 * 60 * 1000;

    /** The index lenght. */
    public static final int INDEX_LENGHT = 5;

    /** The wind direction names. */
    public final static String DIRECTIONS[] = { Resources.get("direction.n"), Resources.get("direction.en"),
            Resources.get("direction.e"), Resources.get("direction.se"), Resources.get("direction.s"),
            Resources.get("direction.sw"), Resources.get("direction.w"), Resources.get("direction.nw") };

    /** The weekdays names. */
    public final static String WEEKDAYS[] = { null, Resources.get("weekday.su"), Resources.get("weekday.mo"),
            Resources.get("weekday.tu"), Resources.get("weekday.we"), Resources.get("weekday.th"),
            Resources.get("weekday.fr"), Resources.get("weekday.sa") };

    /** The time of the day names. */
    public final static String TODS[] = { Resources.get("tod.night"), Resources.get("tod.morning"),
            Resources.get("tod.day"), Resources.get("tod.evening") };

    /** The Celsius degree suffix. */
    public final static String OC = Resources.get("suffix.oc");

    /** The MHg suffix. */
    public final static String MHG = Resources.get("suffix.mhg");

    /** The m/s suffix. */
    public final static String MS = Resources.get("suffix.ms");

    /** The percent suffix. */
    public final static String PERCENT = Resources.get("suffix.percent");

    /** The number of icon types. */
    public final static int N = 8;

    /** The icon tips. */
    public final static String[] ICON_TIPS;

    /** The icons for day and night. */
    public final static Icon[][] ICONS;

    static {
        ICON_TIPS = new String [N];
        ICONS = new Icon [N][2];
        for (int i = 0; i < N; i++) {
            ICON_TIPS[i] = Resources.get("icon.tip." + i);
            ICONS[i][0] = Icons.get(i + "n.png");
            ICONS[i][1] = Icons.get(i + "d.png");
        }
    }

    /**
     * Formats the temperature value.
     * @param temperature the value
     * @return the temperature string
     */
    public static String formatTemperature(int temperature) {
        if (temperature > 0) {
            return "+" + temperature;
        } else {
            return "" + temperature;
        }
    }

    /**
     * Gets the icon.
     * @param precipitation the precipitation
     * @param cloudiness the cloudiness
     * @param tod the time of the day
     * @return the icon
     */
    public static Icon getIcon(int precipitation, int cloudiness, int tod) {
        Icon icon = null;
        int index = getIconIndex(precipitation, cloudiness);
        if (index >= 0 && index < Utils.N) {
            icon = Utils.ICONS[index][tod == Forecast.TOD_NIGHT || tod == Forecast.TOD_EVENING ? 0 : 1];
        }
        return icon;
    }

    /**
     * Gets the icon tip.
     * @param precipitation the precipitation
     * @param cloudiness the cloudiness
     * @return the icon tip
     */
    public static String getIconTip(int precipitation, int cloudiness) {
        String tip = null;
        int index = getIconIndex(precipitation, cloudiness);
        if (index >= 0 && index < Utils.N) {
            tip = Utils.ICON_TIPS[index];
        }
        return tip;
    }

    /**
     * Gets the icon index.
     * @param precipitation the precipitation
     * @param cloudiness the cloudiness
     * @return the icon index
     */
    public static int getIconIndex(int precipitation, int cloudiness) {
        if (precipitation == Phenomena.PRECIPITATION_NONE) {
            return cloudiness;
        } else {
            return precipitation;
        }
    }
}
